"use client";

import React, { useEffect, useState } from "react";
import axios from "axios";
import { useRouter } from "next/navigation";
import { toast } from "react-toastify";
import "react-toastify/dist/ReactToastify.css";
import Image from "next/image";
import Radio from "@mui/material/Radio";
import RadioGroup from "@mui/material/RadioGroup";
import FormControlLabel from "@mui/material/FormControlLabel";
import FormControl from "@mui/material/FormControl";
import FormLabel from "@mui/material/FormLabel";
import { SelectChangeEvent } from "@mui/material/Select";
import Checkbox from "@mui/material/Checkbox";
import {
  FaUser,
  FaEnvelope,
  FaLock,
  FaEye,
  FaEyeSlash,
  FaCity,
} from "react-icons/fa";
import ProfSignup from "@/src/components/ProfSignup";
import { useAuth } from "@/src/context/AuthContext";
import { useAppModeStore, useDashboardStore } from "@/utils/store";
import { APP_MODE } from "@/utils/enums";
import Button from "@/snippets/button/button";
import Link from "next/link";

const ITEM_HEIGHT = 48;
const ITEM_PADDING_TOP = 8;
const MenuProps = {
  PaperProps: {
    style: {
      maxHeight: ITEM_HEIGHT * 4.5 + ITEM_PADDING_TOP,
      width: 250,
    },
  },
};

const Signup = () => {
  const [userRole, setUserRole] = useState("seeking help");
  const [showPassword, setShowPassword] = useState(false);
  const [email, setEmail] = useState<string>("");
  const [password, setPassword] = useState<string>("");
  const [confirmPassword, setConfirmPassword] = useState<string>("");
  const [firstName, setFirstName] = useState<string>("");
  const [lastName, setLastName] = useState<string>("");
  const [city, setCity] = useState<string>("");
  const [postCode, setPostCode] = useState<string>("");

  const togglePasswordVisibility = () => {
    setShowPassword(!showPassword);
  };

  const label = { inputProps: { "aria-label": "Checkbox demo" } };

  const handleUserRoleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setUserRole(event.target.value);
  };

  const { register } = useAuth();
  const router = useRouter();

  const handleSubmit = async (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    try {
      await register(email, password);
      await router.push("/login");
      toast.success("Account successfully registered");
    } catch (error) {
      console.log(error);
      toast.error("Email already in use");
    }
  };

  const { appMode, setAppMode } = useAppModeStore();
  const { setDashboardMode } = useDashboardStore();
  useEffect(() => {
    setAppMode(APP_MODE.USER);
    setDashboardMode("cases");
  }, []);

  return (
    <div>
      <div className="flex justify-center gap-3 font-clashDisplay">
        <div className="w-1/2">
          <Image
            src="/images/Rectangle 16.png"
            alt="signup"
            width="500"
            height="1000"
          />
        </div>
        <div className="p-10 ">
          <div className="bg-[#FFFFFF] w-[35vw] p-7 shadow-2xl border-2 border-gray-200 mx-auto rounded-2xl">
            <h1 className="text-blueaid text-3xl font-extrabold">
              Sign Up with Humanity Aid
            </h1>
            <div className="text-textaid-200 font-bold text-lg">
              Join our community and start receiving the support and assistance
              you need
            </div>
            <div className="text-lg font-bold">
              Create an account below to get started!
            </div>
            <FormControl component="fieldset">
              <FormLabel
                id="demo-row-radio-buttons-group-label"
                className="text-blueaid font-extrabold text-lg"
              >
                User Role:
              </FormLabel>
              <RadioGroup
                row
                aria-labelledby="demo-row-radio-buttons-group-label"
                name="row-radio-buttons-group"
                value={userRole}
                onChange={handleUserRoleChange}
              >
                <FormControlLabel
                  value="seeking help"
                  control={<Radio />}
                  label="Seeking Help"
                  onClick={() => {
                    setAppMode(APP_MODE.USER);
                  }}
                />
                <FormControlLabel
                  value="offering help"
                  control={<Radio />}
                  label="Offering Help"
                  onClick={() => {
                    setAppMode(APP_MODE.PROESSIONAL);
                  }}
                />
              </RadioGroup>
            </FormControl>
            {userRole === "offering help" && <ProfSignup />}
            <div className="max-w-md w-full p-5 ">
              <form onSubmit={handleSubmit}>
                <div className="mb-4">
                  <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                    <span className="mr-2">
                      <FaUser className="ml-2" />
                    </span>
                    <input
                      type="text"
                      name="firstName"
                      placeholder="First Name"
                      value={firstName}
                      onChange={(e) => setFirstName(e.target.value)}
                      className="w-full py-2 px-3 focus:outline-none"
                    />
                  </div>
                </div>
                <div className="mb-4">
                  <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                    <span className="mr-2">
                      <FaUser className="ml-2" />
                    </span>
                    <input
                      type="text"
                      name="lastName"
                      placeholder="Last Name"
                      value={lastName}
                      onChange={(e) => setLastName(e.target.value)}
                      className="w-full py-2 px-3 focus:outline-none"
                    />
                  </div>
                </div>
                <div className="mb-4">
                  <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                    <span className="mr-2">
                      <FaEnvelope className="ml-2" />
                    </span>
                    <input
                      type="email"
                      name="email"
                      placeholder="Email Address"
                      value={email}
                      onChange={(e) => setEmail(e.target.value)}
                      className="w-full py-2 px-3 focus:outline-none"
                    />
                  </div>
                </div>
                <div className="mb-4">
                  <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                    <span className="mr-2">
                      <FaLock className="ml-2" />
                    </span>
                    <input
                      type={showPassword ? "text" : "password"}
                      name="password"
                      placeholder="Password"
                      value={password}
                      onChange={(e) => setPassword(e.target.value)}
                      className="w-full py-2 px-3 focus:outline-none"
                    />
                    <span
                      className="ml-2 mr-2"
                      onClick={togglePasswordVisibility}
                    >
                      {showPassword ? <FaEyeSlash /> : <FaEye />}
                    </span>
                  </div>
                </div>
                {password && (
                  <div className="text-sm ">
                    Password Strength:
                    {password.length < 6
                      ? "Weak"
                      : password.length < 10
                      ? "Medium"
                      : "Strong"}
                  </div>
                )}
                <div className="mb-4">
                  <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                    <span className="mr-2">
                      <FaLock className="ml-2" />
                    </span>
                    <input
                      type={showPassword ? "text" : "password"}
                      name="confirmPassword"
                      placeholder="Confirm Password"
                      value={confirmPassword}
                      onChange={(e) => setConfirmPassword(e.target.value)}
                      className="w-full py-2 px-3 focus:outline-none"
                    />
                    <span
                      className="ml-2 mr-2"
                      onClick={togglePasswordVisibility}
                    >
                      {showPassword ? <FaEyeSlash /> : <FaEye />}
                    </span>
                  </div>
                </div>
                <div className="mb-4">
                  <div className="flex justify-center gap-6">
                    <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                      <span className="mr-2">
                        <FaCity className="ml-2" />
                      </span>
                      <input
                        type="text"
                        name="city"
                        placeholder="City"
                        value={city}
                        onChange={(e) => setCity(e.target.value)}
                        className="w-full py-2 px-3 focus:outline-none"
                      />
                    </div>
                    <div className="flex items-center border-2 border-gray-300 rounded-lg p-1">
                      <span className="mr-2">
                        <FaCity className="ml-2" />
                      </span>
                      <input
                        type="text"
                        name="postCode"
                        placeholder="Post Code"
                        value={postCode}
                        onChange={(e) => setPostCode(e.target.value)}
                        className="w-full py-2 px-3 focus:outline-none"
                      />
                    </div>
                  </div>
                  <div className="flex justify center mt-4">
                    <Checkbox {...label} />
                    <p>
                      By signing up, you agree to our
                      <a href="/" className="text-blueaid">
                        Terms of Service
                      </a>
                      and
                      <a href="/" className="text-blueaid">
                        Privacy Policy
                      </a>
                    </p>
                  </div>
                </div>
                <Link
                  href={
                    appMode === APP_MODE.PROESSIONAL ? "/professional" : "/user"
                  }
                >
                  <Button text="Sign Up" className="w-full" />
                </Link>

                <div className="flex justify-center">
                  <p>Already have an account?</p>
                  <h2>Login Now</h2>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Signup;
